Changelog
=========

Here you can see the full list of changes between each Teev release.

In Development
---------------

Breaking
~~~~~~~~
Starting from this release, Teev supports Python 3.8 and above.


New
~~~


Fixed
~~~~~


Version 0.0.1
~~~~~~~~~~~~~

Released on April 23rd 2022.

- First public preview release.
